@@ -3,7 +3,7 @@ package Sah::Schema::date::dow_num;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our $schema = [int => {
     summary => 'Day-of-week number (1-7, 1=Monday, like DateTime), coercible from English day-of-week name (Mo/mon/MONDAY)',
@@ -44,10 +44,26 @@ Sah::Schema::date::dow_num - Day-of-week number (1-7, 1=Monday, like DateTime),
 
 =head1 VERSION
 
-This document describes version 0.015 of Sah::Schema::date::dow_num (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
+This document describes version 0.016 of Sah::Schema::date::dow_num (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
+=head2 Sample data and validation results against this schema
+
+ ""  # INVALID (Not in 1-7)
+
+ 0  # INVALID (Not in 1-7)
+
+ 1  # valid
+
+ "Tue"  # valid, becomes 2
+
+ 7  # valid
+
+ 8  # INVALID (Not in 1-7)
+
+=head2 Using with Data::Sah
+
 To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
@@ -59,6 +75,8 @@ To check data against this schema (requires L<Data::Sah>):
  # language, like JavaScript. All from the same schema. See its documentation
  # for more details.
 
+=head2 Using with Params::Sah
+
 To validate function parameters against this schema (requires L<Params::Sah>):
 
  use Params::Sah qw(gen_validator);
@@ -70,8 +88,10 @@ To validate function parameters against this schema (requires L<Params::Sah>):
      ...
  }
 
+=head2 Using with Perinci::CmdLine::Lite
+
 To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  # in lib/MyApp.pm
  package
@@ -109,20 +129,6 @@ L<Perinci::CmdLine> to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
-Sample data:
-
- ""  # INVALID (Not in 1-7)
-
- 0  # INVALID (Not in 1-7)
-
- 1  # valid
-
- "Tue"  # valid, becomes 2
-
- 7  # valid
-
- 8  # INVALID (Not in 1-7)
-
 =head1 DESCRIPTION
 
 See also related schemas that coerce from other locales, e.g.
