@@ -3,7 +3,7 @@ package Sah::Schema::date::dow_nums;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our $schema = ['array' => {
     summary => 'Array of required date::dow_num (day-of-week, 1-7, 1=Monday, like DateTime, with coercions)',
@@ -49,10 +49,34 @@ Sah::Schema::date::dow_nums - Array of required date::dow_num (day-of-week, 1-7,
 
 =head1 VERSION
 
-This document describes version 0.015 of Sah::Schema::date::dow_nums (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
+This document describes version 0.016 of Sah::Schema::date::dow_nums (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
+=head2 Sample data and validation results against this schema
+
+ ""  # valid, becomes []
+
+ 1  # valid, becomes [1]
+
+ [1]  # valid
+
+ [1,undef]  # INVALID (Contains undef)
+
+ [1,7]  # valid
+
+ "1,7"  # valid, becomes [1,7]
+
+ ["Mon","SunDAY"]  # valid, becomes [1,7]
+
+ "Mo,SU"  # valid, becomes [1,7]
+
+ [1,7,8]  # INVALID (Has number not in 1-7)
+
+ "1,7,8"  # INVALID (Has number not in 1-7)
+
+=head2 Using with Data::Sah
+
 To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
@@ -64,6 +88,8 @@ To check data against this schema (requires L<Data::Sah>):
  # language, like JavaScript. All from the same schema. See its documentation
  # for more details.
 
+=head2 Using with Params::Sah
+
 To validate function parameters against this schema (requires L<Params::Sah>):
 
  use Params::Sah qw(gen_validator);
@@ -75,8 +101,10 @@ To validate function parameters against this schema (requires L<Params::Sah>):
      ...
  }
 
+=head2 Using with Perinci::CmdLine::Lite
+
 To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  # in lib/MyApp.pm
  package
@@ -114,28 +142,6 @@ L<Perinci::CmdLine> to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
-Sample data:
-
- ""  # valid, becomes []
-
- 1  # valid, becomes [1]
-
- [1]  # valid
-
- [1,undef]  # INVALID (Contains undef)
-
- [1,7]  # valid
-
- "1,7"  # valid, becomes [1,7]
-
- ["Mon","SunDAY"]  # valid, becomes [1,7]
-
- "Mo,SU"  # valid, becomes [1,7]
-
- [1,7,8]  # INVALID (Has number not in 1-7)
-
- "1,7,8"  # INVALID (Has number not in 1-7)
-
 =head1 DESCRIPTION
 
 See also L<Sah::Schema::date::dow_num> which is the schema for the elements.
