@@ -3,7 +3,7 @@ package Sah::Schema::date::month_name::en;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our $schema = [cistr => {
     summary => 'Month name (abbreviated or full, in English)',
@@ -47,10 +47,28 @@ Sah::Schema::date::month_name::en - Month name (abbreviated or full, in English)
 
 =head1 VERSION
 
-This document describes version 0.015 of Sah::Schema::date::month_name::en (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
+This document describes version 0.016 of Sah::Schema::date::month_name::en (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
+=head2 Sample data and validation results against this schema
+
+ ""  # INVALID (Empty string)
+
+ 1  # INVALID (Not month name)
+
+ "jan"  # valid
+
+ "FeB"  # valid
+
+ "March"  # valid
+
+ "foo"  # INVALID (Unknown month name)
+
+ 13  # INVALID (Not month name)
+
+=head2 Using with Data::Sah
+
 To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
@@ -62,6 +80,8 @@ To check data against this schema (requires L<Data::Sah>):
  # language, like JavaScript. All from the same schema. See its documentation
  # for more details.
 
+=head2 Using with Params::Sah
+
 To validate function parameters against this schema (requires L<Params::Sah>):
 
  use Params::Sah qw(gen_validator);
@@ -73,8 +93,10 @@ To validate function parameters against this schema (requires L<Params::Sah>):
      ...
  }
 
+=head2 Using with Perinci::CmdLine::Lite
+
 To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  # in lib/MyApp.pm
  package
@@ -112,22 +134,6 @@ L<Perinci::CmdLine> to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
-Sample data:
-
- ""  # INVALID (Empty string)
-
- 1  # INVALID (Not month name)
-
- "jan"  # valid
-
- "FeB"  # valid
-
- "March"  # valid
-
- "foo"  # INVALID (Unknown month name)
-
- 13  # INVALID (Not month name)
-
 =head1 DESCRIPTION
 
 See also: L<Sah::Schema::date::month_num>.
