@@ -3,7 +3,7 @@ package Sah::Schema::date::month_nums;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our $schema = ['array' => {
     summary => 'Array of required month numbers (1-12, with coercions)',
@@ -47,10 +47,34 @@ Sah::Schema::date::month_nums - Array of required month numbers (1-12, with coer
 
 =head1 VERSION
 
-This document describes version 0.015 of Sah::Schema::date::month_nums (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
+This document describes version 0.016 of Sah::Schema::date::month_nums (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
+=head2 Sample data and validation results against this schema
+
+ ""  # valid, becomes []
+
+ 0  # INVALID (Has number not in 1-12)
+
+ 1  # valid, becomes [1]
+
+ [1]  # valid
+
+ [1,12]  # valid
+
+ [1,undef]  # INVALID (Contains undef)
+
+ ["Jan","JUN"]  # valid, becomes [1,6]
+
+ "January,JUNE"  # valid, becomes [1,6]
+
+ [1,12,13]  # INVALID (Has number not in 1-12)
+
+ "1,12,13"  # INVALID (Has number not in 1-12)
+
+=head2 Using with Data::Sah
+
 To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
@@ -62,6 +86,8 @@ To check data against this schema (requires L<Data::Sah>):
  # language, like JavaScript. All from the same schema. See its documentation
  # for more details.
 
+=head2 Using with Params::Sah
+
 To validate function parameters against this schema (requires L<Params::Sah>):
 
  use Params::Sah qw(gen_validator);
@@ -73,8 +99,10 @@ To validate function parameters against this schema (requires L<Params::Sah>):
      ...
  }
 
+=head2 Using with Perinci::CmdLine::Lite
+
 To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  # in lib/MyApp.pm
  package
@@ -112,28 +140,6 @@ L<Perinci::CmdLine> to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
-Sample data:
-
- ""  # valid, becomes []
-
- 0  # INVALID (Has number not in 1-12)
-
- 1  # valid, becomes [1]
-
- [1]  # valid
-
- [1,12]  # valid
-
- [1,undef]  # INVALID (Contains undef)
-
- ["Jan","JUN"]  # valid, becomes [1,6]
-
- "January,JUNE"  # valid, becomes [1,6]
-
- [1,12,13]  # INVALID (Has number not in 1-12)
-
- "1,12,13"  # INVALID (Has number not in 1-12)
-
 =head1 DESCRIPTION
 
 See also related schemas that coerce from other locales, e.g.
