@@ -3,7 +3,7 @@ package Sah::Schema::date::second;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our $schema = [int => {
     summary => 'Second of minute (0-60)',
@@ -34,10 +34,24 @@ Sah::Schema::date::second - Second of minute (0-60)
 
 =head1 VERSION
 
-This document describes version 0.015 of Sah::Schema::date::second (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
+This document describes version 0.016 of Sah::Schema::date::second (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
+=head2 Sample data and validation results against this schema
+
+ ""  # INVALID (Empty string)
+
+ 0  # valid
+
+ 59  # valid
+
+ 60  # valid
+
+ 61  # INVALID (Not in 0-60)
+
+=head2 Using with Data::Sah
+
 To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
@@ -49,6 +63,8 @@ To check data against this schema (requires L<Data::Sah>):
  # language, like JavaScript. All from the same schema. See its documentation
  # for more details.
 
+=head2 Using with Params::Sah
+
 To validate function parameters against this schema (requires L<Params::Sah>):
 
  use Params::Sah qw(gen_validator);
@@ -60,8 +76,10 @@ To validate function parameters against this schema (requires L<Params::Sah>):
      ...
  }
 
+=head2 Using with Perinci::CmdLine::Lite
+
 To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  # in lib/MyApp.pm
  package
@@ -99,18 +117,6 @@ L<Perinci::CmdLine> to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
-Sample data:
-
- ""  # INVALID (Empty string)
-
- 0  # valid
-
- 59  # valid
-
- 60  # valid
-
- 61  # INVALID (Not in 0-60)
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Date>.
