@@ -3,7 +3,7 @@ package Sah::Schema::date::tz_offset;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 BEGIN {
 
@@ -90,10 +90,38 @@ Sah::Schema::date::tz_offset - Timezone offset in seconds from UTC
 
 =head1 VERSION
 
-This document describes version 0.015 of Sah::Schema::date::tz_offset (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
+This document describes version 0.016 of Sah::Schema::date::tz_offset (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
+=head2 Sample data and validation results against this schema
+
+ ""  # INVALID
+
+ "UTC"  # valid, becomes 0
+
+ 3600  # valid, becomes 3600
+
+ -43200  # valid, becomes -43200
+
+ -12  # valid, becomes -43200
+
+ -1200  # valid, becomes -43200
+
+ "-12:00"  # valid, becomes -43200
+
+ "UTC-12"  # valid, becomes -43200
+
+ "UTC-1200"  # valid, becomes -43200
+
+ "UTC+12:45"  # valid, becomes 45900
+
+ "UTC-13"  # INVALID
+
+ "UTC+12:01"  # INVALID (Unknown offset)
+
+=head2 Using with Data::Sah
+
 To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
@@ -105,6 +133,8 @@ To check data against this schema (requires L<Data::Sah>):
  # language, like JavaScript. All from the same schema. See its documentation
  # for more details.
 
+=head2 Using with Params::Sah
+
 To validate function parameters against this schema (requires L<Params::Sah>):
 
  use Params::Sah qw(gen_validator);
@@ -116,8 +146,10 @@ To validate function parameters against this schema (requires L<Params::Sah>):
      ...
  }
 
+=head2 Using with Perinci::CmdLine::Lite
+
 To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  # in lib/MyApp.pm
  package
@@ -155,32 +187,6 @@ L<Perinci::CmdLine> to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
-Sample data:
-
- ""  # INVALID
-
- "UTC"  # valid, becomes 0
-
- 3600  # valid, becomes 3600
-
- -43200  # valid, becomes -43200
-
- -12  # valid, becomes -43200
-
- -1200  # valid, becomes -43200
-
- "-12:00"  # valid, becomes -43200
-
- "UTC-12"  # valid, becomes -43200
-
- "UTC-1200"  # valid, becomes -43200
-
- "UTC+12:45"  # valid, becomes 45900
-
- "UTC-13"  # INVALID
-
- "UTC+12:01"  # INVALID (Unknown offset)
-
 =head1 DESCRIPTION
 
 Only timezone offsets that are known to exist are allowed. For example, 1 second
